@@ -1,17 +1,15 @@
 """Loaders for demographic information."""
 
-from typing import Optional
+from __future__ import annotations
 
 import pandas as pd
 
 from psycop_feature_generation.loaders.raw.sql_load import sql_load
 from psycop_feature_generation.utils import data_loaders
 
-# pylint: disable=missing-function-docstring
 
-
-@data_loaders.register("birthdays")  # noqa
-def birthdays(n_rows: Optional[int] = None) -> pd.DataFrame:
+@data_loaders.register("birthdays")
+def birthdays(n_rows: int | None = None) -> pd.DataFrame:
     view = "[FOR_kohorte_demografi_inkl_2021_feb2022]"
 
     sql = f"SELECT dw_ek_borger, foedselsdato FROM [fct].{view}"
@@ -22,14 +20,13 @@ def birthdays(n_rows: Optional[int] = None) -> pd.DataFrame:
     # We must handle it manually here
     df["foedselsdato"] = pd.to_datetime(df["foedselsdato"], format="%Y-%m-%d")
 
-    df.rename(columns={"foedselsdato": "date_of_birth"}, inplace=True)
+    df = df.rename(columns={"foedselsdato": "date_of_birth"})
 
-    # msg.good("Loaded birthdays")
     return df.reset_index(drop=True)
 
 
 @data_loaders.register("sex_female")
-def sex_female(n_rows: Optional[int] = None) -> pd.DataFrame:
+def sex_female(n_rows: int | None = None) -> pd.DataFrame:
     view = "[FOR_kohorte_demografi_inkl_2021_feb2022]"
 
     sql = f"SELECT dw_ek_borger, koennavn FROM [fct].{view}"
@@ -39,9 +36,8 @@ def sex_female(n_rows: Optional[int] = None) -> pd.DataFrame:
     df.loc[df["koennavn"] == "Mand", "koennavn"] = False
     df.loc[df["koennavn"] == "Kvinde", "koennavn"] = True
 
-    df.rename(
+    df = df.rename(
         columns={"koennavn": "sex_female"},
-        inplace=True,
     )
 
     return df.reset_index(drop=True)
