@@ -1,6 +1,6 @@
 """Loaders for lab results loading."""
 
-from typing import Optional, Union
+from __future__ import annotations
 
 import pandas as pd
 
@@ -10,14 +10,12 @@ from psycop_feature_generation.loaders.non_numerical_coercer import (
 from psycop_feature_generation.loaders.raw.sql_load import sql_load
 from psycop_feature_generation.utils import data_loaders
 
-# pylint: disable=missing-function-docstring
-
 
 def load_non_numerical_values_and_coerce_inequalities(
-    blood_sample_id: Union[str, list[str]],
-    n_rows: Optional[int],
+    blood_sample_id: str | list[str],
+    n_rows: int | None,
     view: str,
-    ineq2mult: Optional[dict[str, float]] = None,
+    ineq2mult: dict[str, float] | None = None,
 ) -> pd.DataFrame:
     """Load non-numerical values for a blood sample.
 
@@ -34,7 +32,7 @@ def load_non_numerical_values_and_coerce_inequalities(
 
     if isinstance(blood_sample_id, list):
         npu_codes = ", ".join(
-            [f"'{x}'" for x in blood_sample_id],  # pylint: disable=not-an-iterable
+            [f"'{x}'" for x in blood_sample_id],
         )
 
         npu_where = f"npukode in ({npu_codes})"
@@ -50,17 +48,16 @@ def load_non_numerical_values_and_coerce_inequalities(
         n_rows=n_rows,
     )
 
-    df.rename(
+    df = df.rename(
         columns={"datotid_sidstesvar": "timestamp", "svar": "value"},
-        inplace=True,
     )
 
     return multiply_inequalities_in_df(df, ineq2mult=ineq2mult)
 
 
 def load_numerical_values(
-    blood_sample_id: str,
-    n_rows: Optional[int],
+    blood_sample_id: str | list[str],
+    n_rows: int | None,
     view: str,
 ) -> pd.DataFrame:
     """Load numerical values for a blood sample.
@@ -78,7 +75,7 @@ def load_numerical_values(
 
     if isinstance(blood_sample_id, list):
         npu_codes = ", ".join(
-            [f"'{x}'" for x in blood_sample_id],  # pylint: disable=not-an-iterable
+            [f"'{x}'" for x in blood_sample_id],
         )
 
         npu_where = f"npukode in ({npu_codes})"
@@ -93,17 +90,16 @@ def load_numerical_values(
         n_rows=n_rows,
     )
 
-    df.rename(
+    df = df.rename(
         columns={"datotid_sidstesvar": "timestamp", "numerisksvar": "value"},
-        inplace=True,
     )
 
     return df
 
 
 def load_cancelled(
-    blood_sample_id: str,
-    n_rows: Optional[int],
+    blood_sample_id: str | list[str],
+    n_rows: int | None,
     view: str,
 ) -> pd.DataFrame:
     """Load cancelled samples for a blood sample.
@@ -120,7 +116,7 @@ def load_cancelled(
 
     if isinstance(blood_sample_id, list):
         npu_codes = ", ".join(
-            [f"'{x}'" for x in blood_sample_id],  # pylint: disable=not-an-iterable
+            [f"'{x}'" for x in blood_sample_id],
         )
 
         npu_where = f"npukode in ({npu_codes})"
@@ -139,17 +135,16 @@ def load_cancelled(
     # Create the value column == 1, since all timestamps here are from cancelled blood samples
     df["value"] = 1
 
-    df.rename(
+    df = df.rename(
         columns={"datotid_sidstesvar": "timestamp"},
-        inplace=True,
     )
 
     return df
 
 
 def load_all_values(
-    blood_sample_id: str,
-    n_rows: Optional[int],
+    blood_sample_id: str | list[str],
+    n_rows: int | None,
     view: str,
 ) -> pd.DataFrame:
     """Load all samples for a blood sample.
@@ -166,7 +161,7 @@ def load_all_values(
 
     if isinstance(blood_sample_id, list):
         npu_codes = ", ".join(
-            [f"'{x}'" for x in blood_sample_id],  # pylint: disable=not-an-iterable
+            [f"'{x}'" for x in blood_sample_id],
         )
 
         npu_where = f"npukode in ({npu_codes})"
@@ -182,17 +177,16 @@ def load_all_values(
         n_rows=n_rows,
     )
 
-    df.rename(
+    df = df.rename(
         columns={"datotid_sidstesvar": "timestamp", "svar": "value"},
-        inplace=True,
     )
 
     return df
 
 
 def blood_sample(
-    blood_sample_id: Union[str, list],
-    n_rows: Optional[int] = None,
+    blood_sample_id: str | list,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     """Load a blood sample.
@@ -222,9 +216,6 @@ def blood_sample(
             f"values_to_load must be one of {allowed_values_to_load}, not {values_to_load}",
         )
 
-    if values_to_load is None:
-        values_to_load = "all"
-
     fn_dict = {
         "coerce": load_non_numerical_values_and_coerce_inequalities,
         "numerical": load_numerical_values,
@@ -234,12 +225,9 @@ def blood_sample(
 
     sources_to_load = [k for k in fn_dict if k in values_to_load]
 
-    if n_rows:
-        n_rows_per_fn = int(n_rows / len(sources_to_load))
-    else:
-        n_rows_per_fn = None
+    n_rows_per_fn = int(n_rows / len(sources_to_load)) if n_rows else None
 
-    for k in sources_to_load:  # pylint: disable=invalid-name
+    for k in sources_to_load:
         dfs.append(
             fn_dict[k](  # type: ignore
                 blood_sample_id=blood_sample_id,
@@ -249,10 +237,7 @@ def blood_sample(
         )
 
     # Concatenate dfs
-    if len(dfs) > 1:
-        df = pd.concat(dfs)
-    else:
-        df = dfs[0]
+    df = pd.concat(dfs) if len(dfs) > 1 else dfs[0]
 
     return df.reset_index(drop=True).drop_duplicates(
         subset=["dw_ek_borger", "timestamp", "value"],
@@ -262,7 +247,7 @@ def blood_sample(
 
 @data_loaders.register("hba1c")
 def hba1c(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -274,7 +259,7 @@ def hba1c(
 
 @data_loaders.register("scheduled_glc")
 def scheduled_glc(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     npu_suffixes = [
@@ -333,7 +318,7 @@ def scheduled_glc(
 
 @data_loaders.register("arterial_p_glc")
 def arterial_p_glc(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -345,7 +330,7 @@ def arterial_p_glc(
 
 @data_loaders.register("urinary_glc")
 def urinary_p_glc(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -357,7 +342,7 @@ def urinary_p_glc(
 
 @data_loaders.register("unscheduled_p_glc")
 def unscheduled_p_glc(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     npu_suffixes = [
@@ -376,7 +361,7 @@ def unscheduled_p_glc(
 
 @data_loaders.register("ogtt")
 def ogtt(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -388,7 +373,7 @@ def ogtt(
 
 @data_loaders.register("fasting_p_glc")
 def fasting_p_glc(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -400,7 +385,7 @@ def fasting_p_glc(
 
 @data_loaders.register("triglycerides")
 def triglycerides(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -412,7 +397,7 @@ def triglycerides(
 
 @data_loaders.register("fasting_triglycerides")
 def fasting_triglycerides(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -424,7 +409,7 @@ def fasting_triglycerides(
 
 @data_loaders.register("hdl")
 def hdl(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -436,7 +421,7 @@ def hdl(
 
 @data_loaders.register("ldl")
 def ldl(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -448,7 +433,7 @@ def ldl(
 
 @data_loaders.register("fasting_ldl")
 def fasting_ldl(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -460,7 +445,7 @@ def fasting_ldl(
 
 @data_loaders.register("alat")
 def alat(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -472,7 +457,7 @@ def alat(
 
 @data_loaders.register("asat")
 def asat(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -484,7 +469,7 @@ def asat(
 
 @data_loaders.register("lymphocytes")
 def lymphocytes(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -496,7 +481,7 @@ def lymphocytes(
 
 @data_loaders.register("leukocytes")
 def leukocytes(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -508,7 +493,7 @@ def leukocytes(
 
 @data_loaders.register("crp")
 def crp(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -520,7 +505,7 @@ def crp(
 
 @data_loaders.register("creatinine")
 def creatinine(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -532,7 +517,7 @@ def creatinine(
 
 @data_loaders.register("egfr")
 def egfr(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -544,7 +529,7 @@ def egfr(
 
 @data_loaders.register("albumine_creatinine_ratio")
 def albumine_creatinine_ratio(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -556,7 +541,7 @@ def albumine_creatinine_ratio(
 
 @data_loaders.register("cyp21a2")
 def cyp21a2(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -568,7 +553,7 @@ def cyp21a2(
 
 @data_loaders.register("cyp2c19")
 def cyp2c19(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -580,7 +565,7 @@ def cyp2c19(
 
 @data_loaders.register("cyp2c9")
 def cyp2c9(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -592,7 +577,7 @@ def cyp2c9(
 
 @data_loaders.register("cyp3a5")
 def cyp3a5(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -604,7 +589,7 @@ def cyp3a5(
 
 @data_loaders.register("cyp2d6")
 def cyp2d6(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -616,7 +601,7 @@ def cyp2d6(
 
 @data_loaders.register("p_lithium")
 def p_lithium(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -628,7 +613,7 @@ def p_lithium(
 
 @data_loaders.register("p_clozapine")
 def p_clozapine(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -640,7 +625,7 @@ def p_clozapine(
 
 @data_loaders.register("p_olanzapine")
 def p_olanzapine(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -652,7 +637,7 @@ def p_olanzapine(
 
 @data_loaders.register("p_aripiprazol")
 def p_aripiprazol(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -664,7 +649,7 @@ def p_aripiprazol(
 
 @data_loaders.register("p_risperidone")
 def p_risperidone(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -676,7 +661,7 @@ def p_risperidone(
 
 @data_loaders.register("p_paliperidone")
 def p_paliperidone(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -688,7 +673,7 @@ def p_paliperidone(
 
 @data_loaders.register("p_haloperidol")
 def p_haloperidol(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -700,7 +685,7 @@ def p_haloperidol(
 
 @data_loaders.register("p_amitriptyline")
 def p_amitriptyline(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -712,7 +697,7 @@ def p_amitriptyline(
 
 @data_loaders.register("p_nortriptyline")
 def p_nortriptyline(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -724,7 +709,7 @@ def p_nortriptyline(
 
 @data_loaders.register("p_clomipramine")
 def p_clomipramine(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -736,7 +721,7 @@ def p_clomipramine(
 
 @data_loaders.register("p_paracetamol")
 def p_paracetamol(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -748,7 +733,7 @@ def p_paracetamol(
 
 @data_loaders.register("p_ibuprofen")
 def p_ibuprofen(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
@@ -760,7 +745,7 @@ def p_ibuprofen(
 
 @data_loaders.register("p_ethanol")
 def p_ethanol(
-    n_rows: Optional[int] = None,
+    n_rows: int | None = None,
     values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
