@@ -3,10 +3,12 @@
 utilities. If this file grows, consider splitting it up.
 """
 
+from __future__ import annotations
+
 import os
 from collections.abc import Hashable
 from pathlib import Path
-from typing import Any, Optional
+from typing import Any
 
 import catalogue
 import pandas as pd
@@ -45,7 +47,7 @@ def format_dict_for_printing(d: dict) -> str:
 
 def load_dataset_from_file(
     file_path: Path,
-    nrows: Optional[int] = None,
+    nrows: int | None = None,
 ) -> pd.DataFrame:
     """Load dataset from file. Handles csv and parquet files based on suffix.
 
@@ -62,7 +64,7 @@ def load_dataset_from_file(
     if file_suffix == ".csv":
         return pd.read_csv(file_path, nrows=nrows)
 
-    elif file_suffix == ".parquet":
+    elif file_suffix == ".parquet":  # noqa
         if nrows:
             raise ValueError("nrows not supported for parquet files")
 
@@ -146,10 +148,10 @@ def assert_no_duplicate_dicts_in_list(predictor_spec_list: list[dict[str, Any]])
     for d in predictor_spec_list:
         # Remove any keys with unhashable values
         # Otherwise, we get an error when using "in".
-        d = {k: v for k, v in d.items() if isinstance(v, Hashable)}
+        exploded_d = {k: v for k, v in d.items() if isinstance(v, Hashable)}
 
-        d_as_tuple = tuple(d.items())
-        if d_as_tuple in seen:  # pylint: disable=R6103
+        d_as_tuple = tuple(exploded_d.items())
+        if d_as_tuple in seen:
             duplicates.add(d_as_tuple)
         else:
             seen.add(d_as_tuple)
