@@ -2,7 +2,7 @@
 from pathlib import Path
 
 import numpy as np
-from psycopmlutils.synth_data_generator.synth_prediction_times_generator import (
+from psycop_ml_utils.synth_data_generator.synth_prediction_times_generator import (
     generate_synth_data,
 )
 
@@ -32,7 +32,7 @@ if __name__ == "__main__":
 
     synth_df = generate_synth_data(
         predictors=column_specifications,
-        outcome_column_name="outc_dichotomous_t2d_within_30_days_max_fallback_0",
+        outcome_column_name="outc_t2d_within_30_days_max_fallback_0_dichotomous",
         n_samples=10_000,
         logistic_outcome_model="1*pred_hba1c_within_100_days_max_fallback_nan+1*pred_hdl_within_100_days_max_fallback_nan",
         prob_outcome=0.08,
